#
# spec file for package appeditor
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           appeditor
Version:        1.1.5
Release:        1.5
Summary:        Application Entry Editor
License:        GPL-3.0-or-later
Group:          System/GUI/Other
URL:            https://github.com/donadigo/appeditor
Source:         https://github.com/donadigo/appeditor/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM appeditor-1.1.3-fix-flickering-titlebar.patch -- gh#donadigo/appeditor#103
Patch0:         appeditor-1.1.3-fix-flickering-titlebar.patch
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libxml2-tools
BuildRequires:  meson >= 0.40.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(granite) >= 0.5
BuildRequires:  pkgconfig(gtk+-3.0)
Recommends:     %{name}-lang

%description
A program to edit application entries shown in the application menu,
and to edit their properties.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file -r com.github.donadigo.appeditor GTK Utility Settings
%find_lang com.github.donadigo.appeditor %{name}.lang
%fdupes %{buildroot}/%{_datadir}

%files
%doc README.md
%{_bindir}/com.github.donadigo.appeditor
%{_datadir}/applications/com.github.donadigo.appeditor.desktop
%dir %{_datadir}/contractor
%{_datadir}/contractor/com.github.donadigo.appeditor.contract
%{_datadir}/glib-2.0/schemas/com.github.donadigo.appeditor.gschema.xml
%{_datadir}/icons/hicolor/*/apps/com.github.donadigo.appeditor.??g
%{_datadir}/metainfo/com.github.donadigo.appeditor.appdata.xml

%files lang -f %{name}.lang

%changelog
* Fri Dec 22 2023 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 1.1.5:
  * Make AppEditor available in elementary OS 7.
  * New translations: Czech.
- Changes from version 1.1.4:
  * Fix payment not working in the AppCenter.
  * New translations: Swedish.
- Remove appeditor-1.1.3-vala-0.55.1.patch: Fixed upstream.
* Fri Jun 24 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Add appeditor-1.1.3-vala-0.55.1.patch: Fix build with Vala 0.55.1
* Mon Jan 17 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 1.1.3:
  * Fix a warning.
- Changes from version 1.1.2:
  * Add new translation: Portuguese.
  * Fix some Flatpak issues.
  * Fix some typos.
- Add appeditor-1.1.3-fix-flickering-titlebar.patch, picked from
  Fedora (gh#donadigo/appeditor#103).
* Thu Apr 30 2020 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.1:
  * Add dependency gettext in README.md (#93)
  * Fix .desktop issues
  * Fix dash in the npm command
  * Fix compilation on newer valac
  * Update travis to make build successful
  * Merge #84 manually
  * Update .po files
  * Manually merge #66, #62 and #33
  * Add turkish to LINGUAS
  * Update fr.po (#78)
  * Add LICENSE
- Drop appeditor-1.1.0-vala-0.46.patch
* Thu Oct 31 2019 Alexei Podvalsky <avvissu@yandex.by>
- Add appeditor-1.1.0-vala-0.46.patch
* Tue Aug 14 2018 avvissu@yandex.by
- Update to 1.1.0:
  * Fix IconButton CSS for GTK 3.22
  * Remove matrix from travis.yml
  * Conditionally compile Posix constants with Vala >= 0.40
  * Remove debian packaging in favor of separate branches
  * Add find shortcut
  * Add content rating to AppStream data
  * Add missing file
  * Remove deprecations; port to Granite.MessageDialog; add new
    shortcuts for new and duplicating app entries
  * Add support for Gtk 3.22 (Juno)
  * Reflect #56 in ja.po (#57)
  * Fix a typo (#56)
  * Add contractor entry for creating new application menu
    entries from the file manager; update strings
  * Add german language (#39)
  * Fix compilation on systems without the GLib KEY_FULLNAME
    constant
  * Do not escape the display name nor the description
- Remove obsolete macros
* Sat Jul 14 2018 jengelh@inai.de
- Update description.
* Sat Jan 20 2018 avvissu@yandex.by
- Update to 1.0.0:
  * Add a duplicate button
  * Remove the app item from the items list - fix removing non
    existent items from the sidebar; create new application entry
    with the same category of the selected app
  * Fix wrong interpretation of the command line entry: validate
    only the first argument of the Exec key
- Add the package with translations
* Sun Dec 24 2017 avvissu@yandex.by
- Initial package
